@@ -8,7 +8,7 @@
 # Set simulation horizon
 setSimHorizon <- function(startDate, endDate){
   dts <- c(startDate,endDate)
-  simHorizon <- chron(dts,format=c(dates="d/m/Y"),out.format=c(dates="d/m/year"))
+  simHorizon <- chron(dts,format=c(dates='d/m/Y'),out.format=c(dates='d/m/year'))
   return(simHorizon)
 }
 
@@ -21,12 +21,12 @@ buildTransitionMatrix <- function(allTransitions,absTransitions,stateSpace){
   absStates <- absTransitions[,1]  
   if(is.null(dim(stateSpace)))
     stateSpace <- matrix(stateSpace, ncol=1)  
-  absStNam <- c("dead")
-  if("rest" %in% unlist(strsplit(absStates,"/")))
-    absStNam <- c(absStNam, "rest") 
+  absStNam <- c('dead')
+  if('rest' %in% unlist(strsplit(absStates,'/')))
+    absStNam <- c(absStNam, 'rest') 
   transitionMatrix <- matrix(0,nrow=dim(stateSpace)[1], ncol=dim(stateSpace)[1]+length(absStNam))
-  colnames(transitionMatrix) <- c(apply(stateSpace,1,paste,collapse="/"),absStNam)
-  rownames(transitionMatrix) <- apply(stateSpace,1,paste,collapse="/")  
+  colnames(transitionMatrix) <- c(apply(stateSpace,1,paste,collapse='/'),absStNam)
+  rownames(transitionMatrix) <- apply(stateSpace,1,paste,collapse='/')  
   # Function to identify whether a set of attributes (`substates') is part of a state space state
   isInThisState <- function(ss,state){
     if(sum(ss %in% as.character(unlist(state)))==length(ss))
@@ -34,12 +34,12 @@ buildTransitionMatrix <- function(allTransitions,absTransitions,stateSpace){
     return(FALSE)
   }   
   for(i in 1:length(absStates)){
-    strAb <- unlist(strsplit(absStates[i],split="/"))   
+    strAb <- unlist(strsplit(absStates[i],split='/'))   
     if(length(strAb)==1){
       ia <- which(colnames(transitionMatrix)==absStates[i])
       transitionMatrix[,ia] <- absTransitions[i,2]
     } else {
-      iAB <- which(strAb %in% c("dead","rest"))
+      iAB <- which(strAb %in% c('dead','rest'))
       aS <- strAb[iAB]
       strAbCov <- strAb[-iAB]
       rA <- which(apply(stateSpace,1,isInThisState, ss=strAbCov)==TRUE)
@@ -48,11 +48,11 @@ buildTransitionMatrix <- function(allTransitions,absTransitions,stateSpace){
     }
   }        
   if(!is.null(allTransitions)){
-    tr <- do.call(rbind,strsplit(allTransitions[,1],"->"))
+    tr <- do.call(rbind,strsplit(allTransitions[,1],'->'))
     for(i in 1: dim(tr)[1]){
       trI <- tr[i,]
-      oSPr <- unlist(strsplit(trI[1], split="/"))
-      dSPr <- unlist(strsplit(trI[2], split="/"))
+      oSPr <- unlist(strsplit(trI[1], split='/'))
+      dSPr <- unlist(strsplit(trI[2], split='/'))
       idOS <- apply(stateSpace,1,isInThisState, ss=oSPr)
       idDS <- apply(stateSpace,1,isInThisState, ss=dSPr)
       stateSpaceOS <- stateSpace[idOS,,drop=F]
@@ -64,8 +64,8 @@ buildTransitionMatrix <- function(allTransitions,absTransitions,stateSpace){
           c1 <- oS[!oS %in% oSPr] 
           c2 <- dS[!dS %in% dSPr] 
           if(sum(!(c1 %in% c2))==0 & sum(!(c2 %in% c1))==0){
-            ir <- which(rownames(transitionMatrix)==paste(oS, collapse="/"))
-            ic <- which(colnames(transitionMatrix)==paste(dS, collapse="/"))
+            ir <- which(rownames(transitionMatrix)==paste(oS, collapse='/'))
+            ic <- which(colnames(transitionMatrix)==paste(dS, collapse='/'))
             transitionMatrix[ir,ic] <- allTransitions[i,2]
           }          
         }       
